# cygnusdatautils

## Installing:

```
pip install cygnusdatautils
```

## Usage:

```python
import cygnusdatautils as cdu

connection = cdu.get_postgresql_connector( 'host', 'port', 'username', 'password', 'database')

```